@@ -21,6 +21,7 @@
 */
 
 #include <config.h>
+#include <libgnome/gnome-i18n.h>
 #include <string.h>
 #include <gal/widgets/widget-color-combo.h>
 #include "htmlengine-edit.h"
@@ -246,13 +247,13 @@ body_properties (GtkHTMLControlData *cd, gpointer *set_data)
 	data->left_margin = 10;
 
 	table = gtk_table_new (2, 2, FALSE);
-	gtk_container_set_border_width (GTK_CONTAINER (table), 3);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 3);
-	gtk_table_set_row_spacings (GTK_TABLE (table), 2);
+	gtk_container_set_border_width (GTK_CONTAINER (table), 12);
+	gtk_table_set_col_spacings (GTK_TABLE (table), 12);
+	gtk_table_set_row_spacings (GTK_TABLE (table), 4);
 
-	vb1 = gtk_vbox_new (FALSE, 0);
-	hbox = gtk_hbox_new (FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox), 3);
+	vb1 = gtk_vbox_new (FALSE, 6);
+	hbox = gtk_hbox_new (FALSE, 12);
+	gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
 	frame = gtk_frame_new (_("Template"));
 	data->option_template = gtk_option_menu_new ();
 	fill_templates (data);
@@ -262,8 +263,8 @@ body_properties (GtkHTMLControlData *cd, gpointer *set_data)
 	gtk_container_add (GTK_CONTAINER (frame), hbox);
 	gtk_box_pack_start (GTK_BOX (vb1), frame, FALSE, TRUE, 0);
 	
-	hbox = gtk_hbox_new (FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox), 3);
+	hbox = gtk_hbox_new (FALSE, 12);
+	gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
 	data->entry_title = gtk_entry_new ();
 	if (gtk_html_get_title (data->cd->html)) {
 		gtk_entry_set_text (GTK_ENTRY (data->entry_title), 
@@ -276,8 +277,8 @@ body_properties (GtkHTMLControlData *cd, gpointer *set_data)
 	gtk_box_pack_start (GTK_BOX (vb1), frame, FALSE, TRUE, 0);	
 
 	frame = gtk_frame_new (_("Background Image"));
-	vbox = gtk_vbox_new (FALSE, 2);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox), 3);
+	vbox = gtk_vbox_new (FALSE, 4);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
 	data->pixmap_entry = gnome_pixmap_entry_new ("background_image", _("Background Image"), FALSE);
 
 	if (cd->html->engine->bgPixmapPtr) {
@@ -302,7 +303,7 @@ body_properties (GtkHTMLControlData *cd, gpointer *set_data)
 
 	frame = gtk_frame_new (_("Colors"));
 	vbox = gtk_vbox_new (FALSE, 2);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox), 3);
+	gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
 
 	group = NULL;
 	i = 0;
@@ -316,7 +317,7 @@ body_properties (GtkHTMLControlData *cd, gpointer *set_data)
         color_combo_set_color (COLOR_COMBO (combo), &data->color [ct]); \
         g_object_set_data (G_OBJECT (combo), "type", GINT_TO_POINTER (ct)); \
         g_signal_connect (combo, "color_changed", G_CALLBACK (color_changed), data); \
-	hbox = gtk_hbox_new (FALSE, 3); \
+	hbox = gtk_hbox_new (FALSE, 12); \
 	gtk_box_pack_start (GTK_BOX (hbox), combo, FALSE, FALSE, 0); \
 	gtk_box_pack_start (GTK_BOX (hbox), gtk_label_new (x), FALSE, FALSE, 0); \
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0); \
