@@ -20,6 +20,8 @@
     Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
+#include <libgnome/gnome-i18n.h>
 #include <string.h>
 #include <glade/glade.h>
 #include <gal/widgets/widget-color-combo.h>
@@ -38,7 +40,6 @@
 #include "htmltablecell.h"
 #include "htmlsettings.h"
 
-#include "config.h"
 #include "properties.h"
 #include "cell.h"
 #include "utils.h"
