@@ -26,7 +26,7 @@
 
 #include <config.h>
 #include <string.h>
-#include <gal/unicode/gunicode.h>
+
 #include "config.h"
 #include "htmlcolor.h"
 #include "htmlengine.h"
@@ -310,6 +310,7 @@ html_engine_save (HTMLEngine *engine,
 	state.receiver = receiver;
 	state.br_count = 0;
 	state.error = FALSE;
+	state.inline_frames = FALSE;
 	state.user_data = user_data;
 	state.last_level = 0;
 
@@ -344,6 +345,7 @@ html_engine_save_plain (HTMLEngine *engine,
 	state.receiver = receiver;
 	state.br_count = 0;
 	state.error = FALSE;
+	state.inline_frames = FALSE;
 	state.user_data = user_data;
 	state.last_level = 0;
 
@@ -391,7 +393,7 @@ html_engine_save_buffer_peek_text (HTMLEngineSaveState *state)
 }
 
 HTMLEngineSaveState *
-html_engine_save_buffer_new (HTMLEngine *engine)
+html_engine_save_buffer_new (HTMLEngine *engine, gboolean inline_frames)
 {
 	HTMLEngineSaveState *state = g_new0 (HTMLEngineSaveState, 1);
 
@@ -400,6 +402,7 @@ html_engine_save_buffer_new (HTMLEngine *engine)
 		state->receiver = (HTMLEngineSaveReceiverFn)html_engine_save_buffer_receiver;
 		state->br_count = 0;
 		state->error = FALSE;
+		state->inline_frames = inline_frames;
 		state->user_data = (gpointer) g_string_new ("");
 		state->last_level = 0;
 	}
@@ -464,3 +467,21 @@ html_engine_save_get_paragraph_align (GtkHTMLParagraphAlignment align)
 
 	return NULL;
 }
+
+gint
+html_engine_save_string_append_nonbsp (GString *out, const guchar *s, guint length)
+{	
+	guint len = length;
+	
+	while (len--) {
+		if (IS_UTF8_NBSP (s)) {
+			g_string_append_c (out, ' ');
+			s += 2;
+			len--;
+		} else {
+			g_string_append_c (out, *s);
+			s++;
+		}
+	}
+	return length;
+}
