@@ -780,6 +780,18 @@ html_object_set_parent (HTMLObject *o, HTMLObject *parent)
 	o->parent = parent;
 }
 
+
+static void
+frame_offset (HTMLObject *o, 
+	      gint *x_return, gint *y_return)
+{
+	if (html_object_is_frame (o)) {
+		HTMLEngine *e = html_object_get_engine (o, NULL);
+		*x_return -= e->x_offset;
+		*y_return -= e->y_offset;
+	} 
+}
+
 void
 html_object_calc_abs_position (HTMLObject *o,
 			       gint *x_return, gint *y_return)
@@ -790,10 +802,14 @@ html_object_calc_abs_position (HTMLObject *o,
 
 	*x_return = o->x;
 	*y_return = o->y;
+	
+	frame_offset (o, x_return, y_return);
 
 	for (p = o->parent; p != NULL; p = p->parent) {
 		*x_return += p->x;
 		*y_return += p->y - p->ascent;
+		
+		frame_offset (p, x_return, y_return);
 	}
 }
 
@@ -1397,7 +1413,7 @@ html_object_cursor_backward (HTMLObject *self, HTMLCursor *cursor)
 		return FALSE;
 
 	if (cursor->offset > 1 || (cursor->offset > 0 && (! (prev = html_object_prev_not_slave (self))
-							  || HTML_IS_CLUEALIGNED (prev)))) {
+							  || HTML_IS_CLUEALIGNED (prev) || !html_object_accepts_cursor (prev)))) {
 		cursor->offset --;
 		cursor->position --;
 		return TRUE;
@@ -1496,11 +1512,22 @@ next_object_uptree_cursor (HTMLObject *obj, HTMLObject * (*next_fn ) (HTMLObject
 /* go down in tree to leaf in way given by down_fn children */
 
 static HTMLObject *
-move_object_downtree_cursor (HTMLObject *obj, HTMLObject * (*down_fn ) (HTMLObject *))
+move_object_downtree_cursor (HTMLObject *obj, HTMLObject * (*down_fn ) (HTMLObject *), HTMLObject * (*next_fn ) (HTMLObject *))
 {
+	HTMLObject *last_obj = obj;
+
 	while ((obj = (*down_fn) (obj))) {
 		if (html_object_accepts_cursor (obj))
 			break;
+		last_obj = obj;
+	}
+
+	if (!obj && last_obj) {
+		obj = last_obj;
+
+		while ((obj = (*next_fn) (obj)))
+			if (html_object_accepts_cursor (obj))
+				break;
 	}
 
 	return obj;
@@ -1516,7 +1543,7 @@ move_object_cursor (HTMLObject *obj, gint *offset, gboolean forward,
 		gboolean found = FALSE;
 		if (((*offset == 0 && forward) || (*offset && !forward)) && html_object_is_container (obj))
 			if ((down = (*down_fn) (obj))) {
-				down = move_object_downtree_cursor (down, down_fn);
+				down = move_object_downtree_cursor (down, down_fn, next_fn);
 				if (down) {
 					if (html_object_is_container (down))
 						*offset = forward ? 0 : 1;
@@ -1536,7 +1563,7 @@ move_object_cursor (HTMLObject *obj, gint *offset, gboolean forward,
 					found = TRUE;
 				} else {
 					HTMLObject *down;
-					down = move_object_downtree_cursor (obj, down_fn);
+					down = move_object_downtree_cursor (obj, down_fn, next_fn);
 					if (down) {
 						if (html_object_is_container (down))
 							*offset = forward ? 0 : 1;
